@@ -431,7 +431,7 @@ class A3eActionEditorGUI extends JPanel implements ActionListener {
                 T t = actionEditor.getPartData(bn);
                 t = catalog2CenteredVRML(bn,t);
                 vrml.setScale(t.scale);
-                vrml.setRot(t.rot);
+                vrml.setQuat(t.quat);
                 vrml.setLoc2(t.offset);
                 vrmls.put(bn,vrml);
             }
@@ -505,7 +505,6 @@ class A3eActionEditorGUI extends JPanel implements ActionListener {
         measureCB.setSelected(false);
         boneCB.removeAllItems();
         boneCB.addItem("[none]");
-        String allBones[] = {};
         if (skeleton!=null) {
             for (String bn : skeleton.getBones()) {
                 boneCB.addItem(bn);
@@ -1071,10 +1070,9 @@ class A3eActionEditorGUI extends JPanel implements ActionListener {
         tt.offset = Util.trans(actionQuatRev,tt.offset);
         tt.offset.sub(bvhOffset);
 
-        Quat4d boneQuat = Util.euler2quat(t.rot);
+        Quat4d boneQuat = t.quat;
         boneQuat.mul(actionQuatRev,boneQuat);
-        tt.rot = Util.quat2euler(boneQuat);
-        tt.rot.scale(180.0/Math.PI);
+        tt.quat = boneQuat;
         tt.scale = t.scale/actionScale;
         return tt;
     }
@@ -1096,9 +1094,7 @@ class A3eActionEditorGUI extends JPanel implements ActionListener {
             bvhOffset = new Vector3d();
         }
         Vector3d boneOffset = new Vector3d(t.offset);//CATALOG.XMLから来る骨のオフセット
-        Vector3d v = new Vector3d(t.rot);
-        v.scale(Math.PI/180.0);
-        Quat4d boneQuat = Util.euler2quat(v);//CATALOC.XMLから来る骨の回転
+        Quat4d boneQuat = t.quat;//CATALOC.XMLから来る骨の回転
         double boneScale = t.scale;//CATALOG.XMLから来る骨のスケール
 
         T tt = new T();
@@ -1109,7 +1105,7 @@ class A3eActionEditorGUI extends JPanel implements ActionListener {
         tt.offset.add(actionOffset);
         Quat4d quat = new Quat4d();
         quat.mul(actionQuat,boneQuat);
-        tt.rot = Util.quat2euler(quat);
+        tt.quat = quat;
         tt.scale = boneScale*actionScale;
         return tt;
     }
@@ -1297,38 +1293,33 @@ class A3eActionEditorGUI extends JPanel implements ActionListener {
 
     class SkeletonEdit extends Edit {
         Vector3d oldOffset;
-        Vector3d oldRot;//ラジアンで保存
+        Quat4d oldQuat;
         double oldScale;
         Vector3d newOffset;
-        Vector3d newRot;//ラジアンで保存
+        Quat4d newQuat;
         double newScale;
         SkeletonEdit() {
             oldOffset = actionEditor.getOffset();
-            oldRot = actionEditor.getRot();
-            oldRot.scale(Math.PI/180.0);
+            oldQuat = actionEditor.getQuat();
             oldScale = actionEditor.getScale();
             newOffset = skeleton.getLoc();
-            newRot = skeleton.getRot();
+            newQuat = skeleton.getQuat();
             newScale = skeleton.getScale();
         }
         void edit(){
             actionEditor.setScale(newScale);
-            Vector3d v = new Vector3d(newRot);
-            v.scale(180.0/Math.PI);
             actionEditor.setOffset(newOffset);
-            actionEditor.setRot(v);
+            actionEditor.setQuat(newQuat);
             skeleton.setScale(newScale);
-            skeleton.setRot(newRot);
+            skeleton.setQuat(newQuat);
             skeleton.setLoc(newOffset);
         }
         void undo(){
             actionEditor.setScale(oldScale);
-            Vector3d v = new Vector3d(oldRot);
-            v.scale(180.0/Math.PI);
-            actionEditor.setRot(v);
+            actionEditor.setQuat(oldQuat);
             actionEditor.setOffset(oldOffset);
             skeleton.setScale(oldScale);
-            skeleton.setRot(oldRot);
+            skeleton.setQuat(oldQuat);
             skeleton.setLoc(oldOffset);
         }
     }
@@ -1338,44 +1329,44 @@ class A3eActionEditorGUI extends JPanel implements ActionListener {
     class PartEdit extends Edit {
         String boneName;
         Vector3d oldOffset = new Vector3d();
-        Vector3d oldRot = new Vector3d();
+        Quat4d oldQuat = new Quat4d();
         double oldScale;
         Vector3d newOffset;
-        Vector3d newRot;
+        Quat4d newQuat;
         double newScale;
         PartEdit(CenteredVRML target) {
             boneName = getBoneName(target);
             T t = actionEditor.getPartData(boneName);
             t = catalog2CenteredVRML(boneName,t);
             oldOffset = t.offset;
-            oldRot = t.rot;
+            oldQuat = t.quat;
             oldScale = t.scale;
             newOffset = target.getLoc2();
-            newRot = target.getRot();
+            newQuat = target.getQuat();
             newScale = target.getScale();
         }
         void edit(){
             T t = new T();
             t.offset = newOffset;
-            t.rot = newRot;
+            t.quat = newQuat;
             t.scale = newScale;
             t = centeredVRML2CATALOG(boneName,t);
             actionEditor.setPartData(boneName,t);
             CenteredVRML target = vrmls.get(boneName);
-            target.setRot(newRot);
+            target.setQuat(newQuat);
             target.setScale(newScale);
             target.setLoc2(newOffset);
         }
         void undo(){
             T t = new T();
             t.offset = oldOffset;
-            t.rot = oldRot;
+            t.quat = oldQuat;
             t.scale = oldScale;
             t = centeredVRML2CATALOG(boneName,t);
             actionEditor.setPartData(boneName,t);
             CenteredVRML target = vrmls.get(boneName);
             target.setScale(oldScale);
-            target.setRot(oldRot);
+            target.setQuat(oldQuat);
             target.setLoc2(oldOffset);
         }
     }
